summaryrefslogtreecommitdiff
path: root/NxWidgets/nxwm/include
diff options
context:
space:
mode:
Diffstat (limited to 'NxWidgets/nxwm/include')
-rw-r--r--NxWidgets/nxwm/include/chexcalculator.hxx4
-rw-r--r--NxWidgets/nxwm/include/cmediaplayer.hxx2
-rw-r--r--NxWidgets/nxwm/include/cnxterm.h (renamed from NxWidgets/nxwm/include/cnxconsole.hxx)46
-rw-r--r--NxWidgets/nxwm/include/cwindowmessenger.hxx2
-rw-r--r--NxWidgets/nxwm/include/nxwmconfig.hxx24
5 files changed, 39 insertions, 39 deletions
diff --git a/NxWidgets/nxwm/include/chexcalculator.hxx b/NxWidgets/nxwm/include/chexcalculator.hxx
index fc5de07b6..7a19567cb 100644
--- a/NxWidgets/nxwm/include/chexcalculator.hxx
+++ b/NxWidgets/nxwm/include/chexcalculator.hxx
@@ -44,7 +44,7 @@
#include <sys/types.h>
#include <nuttx/nx/nxtk.h>
-#include <nuttx/nx/nxconsole.h>
+#include <nuttx/nx/nxterm.h>
#include "cbuttonarray.hxx"
#include "clabel.hxx"
@@ -70,7 +70,7 @@
namespace NxWM
{
/**
- * This class implements the NxConsole application.
+ * This class implements the NxTerm application.
*/
class CHexCalculator : public IApplication,
diff --git a/NxWidgets/nxwm/include/cmediaplayer.hxx b/NxWidgets/nxwm/include/cmediaplayer.hxx
index f36036a2a..a5597d06b 100644
--- a/NxWidgets/nxwm/include/cmediaplayer.hxx
+++ b/NxWidgets/nxwm/include/cmediaplayer.hxx
@@ -46,7 +46,7 @@
#include <sys/types.h>
#include <nuttx/nx/nxtk.h>
-#include <nuttx/nx/nxconsole.h>
+#include <nuttx/nx/nxterm.h>
#include "cnxfont.hxx"
#include "cimage.hxx"
diff --git a/NxWidgets/nxwm/include/cwindowmessenger.hxx b/NxWidgets/nxwm/include/cwindowmessenger.hxx
index 3822813d1..bfe6e9d08 100644
--- a/NxWidgets/nxwm/include/cwindowmessenger.hxx
+++ b/NxWidgets/nxwm/include/cwindowmessenger.hxx
@@ -46,7 +46,7 @@
#include <nuttx/wqueue.h>
#include <nuttx/nx/nxtk.h>
-#include <nuttx/nx/nxconsole.h>
+#include <nuttx/nx/nxterm.h>
#include "cwindoweventhandler.hxx"
#include "cwidgetstyle.hxx"
diff --git a/NxWidgets/nxwm/include/nxwmconfig.hxx b/NxWidgets/nxwm/include/nxwmconfig.hxx
index a7578a206..42b091b27 100644
--- a/NxWidgets/nxwm/include/nxwmconfig.hxx
+++ b/NxWidgets/nxwm/include/nxwmconfig.hxx
@@ -57,7 +57,7 @@
* CONFIG_HAVE_CXX : C++ support is required
* CONFIG_NX : NX must enabled
* CONFIG_NX_MULTIUSER=y : NX must be configured in multiuse mode
- * CONFIG_NXTERM=y : For NxConsole support
+ * CONFIG_NXTERM=y : For NxTerm support
* CONFIG_SCHED_ONEXIT : Support for on_exit()
*
* General settings:
@@ -85,12 +85,12 @@
#endif
/**
- * NxConsole support is (probably) required if CONFIG_NXWM_NXTERM is
+ * NxTerm support is (probably) required if CONFIG_NXWM_NXTERM is
* selected
*/
#if defined(CONFIG_NXWM_NXTERM) && !defined(CONFIG_NXTERM)
-# warning "NxConsole support may be needed (CONFIG_NXTERM)"
+# warning "NxTerm support may be needed (CONFIG_NXTERM)"
#endif
/**
@@ -363,24 +363,24 @@
# define CONFIG_NXWM_STARTWINDOW_STACKSIZE 2048
#endif
-/* NxConsole Window *********************************************************/
+/* NxTerm Window *********************************************************/
/**
- * NxConsole Window Configuration
+ * NxTerm Window Configuration
*
- * CONFIG_NXWM_NXTERM_PRIO - Priority of the NxConsole task. Default:
+ * CONFIG_NXWM_NXTERM_PRIO - Priority of the NxTerm task. Default:
* SCHED_PRIORITY_DEFAULT. NOTE: This priority should be less than
* CONFIG_NXWIDGETS_SERVERPRIO or else there may be data overrun errors.
* Such errors would most likely appear as duplicated rows of data on the
* display.
* CONFIG_NXWM_NXTERM_STACKSIZE - The stack size to use when starting the
- * NxConsole task. Default: 2048 bytes.
- * CONFIG_NXWM_NXTERM_WCOLOR - The color of the NxConsole window background.
+ * NxTerm task. Default: 2048 bytes.
+ * CONFIG_NXWM_NXTERM_WCOLOR - The color of the NxTerm window background.
* Default: MKRGB(192,192,192)
* CONFIG_NXWM_NXTERM_FONTCOLOR - The color of the fonts to use in the
- * NxConsole window. Default: MKRGB(0,0,0)
- * CONFIG_NXWM_NXTERM_FONTID - The ID of the font to use in the NxConsole
+ * NxTerm window. Default: MKRGB(0,0,0)
+ * CONFIG_NXWM_NXTERM_FONTID - The ID of the font to use in the NxTerm
* window. Default: CONFIG_NXWM_DEFAULT_FONTID
- * CONFIG_NXWM_NXTERM_ICON - The glyph to use as the NxConsole icon
+ * CONFIG_NXWM_NXTERM_ICON - The glyph to use as the NxTerm icon
*/
#ifdef CONFIG_NXWM_NXTERM
@@ -410,7 +410,7 @@
# endif
/**
- * The NxConsole window glyph
+ * The NxTerm window glyph
*/
# ifndef CONFIG_NXWM_NXTERM_ICON
diff --git a/NxWidgets/nxwm/include/cnxconsole.hxx b/NxWidgets/nxwm/include/cnxterm.h
index 52fee386a..c97e3b911 100644
--- a/NxWidgets/nxwm/include/cnxconsole.hxx
+++ b/NxWidgets/nxwm/include/cnxterm.h
@@ -1,5 +1,5 @@
/****************************************************************************
- * NxWidgets/nxwm/include/cnxconsole.hxx
+ * NxWidgets/nxwm/include/cnxterm.hxx
*
* Copyright (C) 2012 Gregory Nutt. All rights reserved.
* Author: Gregory Nutt <gnutt@nuttx.org>
@@ -33,8 +33,8 @@
*
****************************************************************************/
-#ifndef __INCLUDE_CNXCONSOLE_HXX
-#define __INCLUDE_CNXCONSOLE_HXX
+#ifndef __INCLUDE_CNXTERM_HXX
+#define __INCLUDE_CNXTERM_HXX
/****************************************************************************
* Included Files
@@ -44,7 +44,7 @@
#include <sys/types.h>
#include <nuttx/nx/nxtk.h>
-#include <nuttx/nx/nxconsole.h>
+#include <nuttx/nx/nxterm.h>
#include "iapplication.hxx"
#include "capplicationwindow.hxx"
@@ -72,27 +72,27 @@ namespace NxWM
bool nshlibInitialize(void);
/**
* This class implements the NxConsole application.
*/
- class CNxConsole : public IApplication, private IApplicationCallback
+ class CNxTerm : public IApplication, private IApplicationCallback
{
private:
CTaskbar *m_taskbar; /**< Reference to the "parent" taskbar */
CApplicationWindow *m_window; /**< Reference to the application window */
- NXCONSOLE m_nxcon; /**< NxConsole handle */
- pid_t m_pid; /**< Task ID of the NxConsole thread */
+ NXTERMi m_nxcon; /**< NxTerm handle */
+ pid_t m_pid; /**< Task ID of the NxTerm thread */
/**
* This is the NxConsole task. This function first redirects output to the
* console window then calls to start the NSH logic.
*/
- static int nxconsole(int argc, char *argv[]);
+ static int nxterm(int argc, char *argv[]);
/**
* This is the NxConsole task exit handler. It is registered with on_exit()
* and called automatically when the nxconsole task exits.
*/
static void exitHandler(int code, FAR void *arg);
@@ -111,7 +111,7 @@ namespace NxWM
public:
/**
- * CNxConsole constructor
+ * CNxTerm constructor
*
* @param window. The application window
*
@@ -119,13 +119,13 @@ namespace NxWM
* @param window. The window to be used by this application.
*/
- CNxConsole(CTaskbar *taskbar, CApplicationWindow *window);
+ CNxTerm(CTaskbar *taskbar, CApplicationWindow *window);
/**
- * CNxConsole destructor
+ * CNxTerm destructor
*/
- ~CNxConsole(void);
+ ~CNxTerm(void);
/**
* Each implementation of IApplication must provide a method to recover
@@ -203,28 +203,28 @@ namespace NxWM
bool isFullScreen(void) const;
};
- class CNxConsoleFactory : public IApplicationFactory
+ class CNxTermFactory : public IApplicationFactory
{
private:
CTaskbar *m_taskbar; /**< The taskbar */
public:
/**
- * CNxConsoleFactory Constructor
+ * CNxTermFactory Constructor
*
* @param taskbar. The taskbar instance used to terminate calibration
*/
- CNxConsoleFactory(CTaskbar *taskbar);
+ CNxTermFactory(CTaskbar *taskbar);
/**
- * CNxConsoleFactory Destructor
+ * CNxTermFactory Destructor
*/
- inline ~CNxConsoleFactory(void) { }
+ inline ~CNxTermFactory(void) { }
/**
* Create a new instance of an CNxConsole (as IApplication).
*/
IApplication *create(void);
@@ -242,4 +242,4 @@ namespace NxWM
}
#endif // __cplusplus
-#endif // __INCLUDE_CNXCONSOLE_HXX
+#endif // __INCLUDE_CNXTERM_HXX
@@ -72,27 +72,27 @@ namespace NxWM
bool nshlibInitialize(void);
/**
- * This class implements the NxConsole application.
+ * This class implements the NxTerm application.
*/
@@ -72,27 +72,27 @@ namespace NxWM
/**
- * This is the NxConsole task. This function first redirects output to the
+ * This is the NxTerm task. This function first redirects output to the
* console window then calls to start the NSH logic.
*/
@@ -72,27 +72,27 @@ namespace NxWM
/**
- * This is the NxConsole task exit handler. It is registered with on_exit()
- * and called automatically when the nxconsole task exits.
+ * This is the NxTerm task exit handler. It is registered with on_exit()
+ * and called automatically when the nxterm task exits.
*/
static void exitHandler(int code, FAR void *arg);
@@ -203,28 +203,28 @@ namespace NxWM
/**
- * Create a new instance of an CNxConsole (as IApplication).
+ * Create a new instance of an CNxTerm (as IApplication).
*/
IApplication *create(void);